@@ -6,6 +6,7 @@ from musicscore.musictree.midi import Midi
 from musicscore.musictree.treechordflags import TreeChordFlag
 from musicscore.musictree.treechordflags2 import TreeChordFlag2
 from musicscore.musictree.treechordflags3 import TreeChordFlag3
+from musicscore.musictree.treeclef import TreeClef
 from musicscore.musictree.treenote import TreeNote
 from musicscore.musicxml.elements.fullnote import Chord, FullNote
 from musicscore.musicxml.elements.note import Cue, Tie, Instrument, Play, Lyric, Notations, Stem, TimeModification, \
@@ -26,16 +27,14 @@ from musicscore.musicxml.types.complextypes.ornaments import Tremolo
 from musicscore.musicxml.types.complextypes.timemodification import ActualNotes, NormalNotes, NormalType
 
 
-class FingerTremolo(object):
-    def __init__(self, chord, number=3, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.chord = chord
-        self.number = number
+# class FingerTremolo(object):
+#     def __init__(self, chord, number=3, *args, **kwargs):
+#         super().__init__(*args, **kwargs)
+#         self.chord = chord
+#         self.number = number
 
 
 class TreeChord(XMLTree):
-    """"""
-
     _DTD = Sequence(
         Choice(
             Sequence(
@@ -76,6 +75,8 @@ class TreeChord(XMLTree):
         self.zero_mode = zero_mode
         self.quarter_duration = quarter_duration
         self._midis = None
+        self._pre_grace_chords = []
+        self._post_grace_chords = []
 
         self.midis = midis
         self._tail = False
@@ -83,18 +84,14 @@ class TreeChord(XMLTree):
         self._is_adjoinable = True
         self._flags = None
 
-        self.manual_type = False
+        self._manual_type = False
+        self._manual_dots = False
         self.manual_voice_number = False
         self.is_finger_tremolo = False
         self.relative_x = None
         self.tie_orientation = None
 
-    @property
-    def is_head(self):
-        return self._head
-
-    def is_tail(self):
-        return self._tail
+    # \\\properties
 
     @property
     def __name__(self):
@@ -105,9 +102,6 @@ class TreeChord(XMLTree):
     def quarter_duration(self):
         return self._quarter_duration
 
-    def set_voice_number(self, voice_number):
-        self.manual_voice_number = voice_number
-
     @quarter_duration.setter
     def quarter_duration(self, value):
         if not isinstance(value, int) and not isinstance(value, float) and not isinstance(value, Fraction):
@@ -117,10 +111,19 @@ class TreeChord(XMLTree):
             raise ValueError('quarter_duration {} must be zero or positive'.format(value))
 
         if not isinstance(self.quarter_duration, Fraction):
-            self._quarter_duration = Fraction(value).limit_denominator(1000)
+            self._quarter_duration = Fraction(value)
+            # self._quarter_duration = Fraction(value).limit_denominator(1000)
         else:
             self._quarter_duration = value
 
+    @property
+    def is_head(self):
+        return self._head
+
+    @property
+    def is_tail(self):
+        return self._tail
+
     @property
     def zero_mode(self):
         return self._zero_mode
@@ -158,21 +161,6 @@ class TreeChord(XMLTree):
 
         self._midis = output
 
-    def add_midi(self, val):
-        if val == 0:
-            raise ValueError('midi with value 0 can not be added.')
-
-        if not isinstance(val, Midi):
-            val = Midi(val)
-
-        self._midis.append(val)
-
-    def add_harmonic(self, interval):
-        if len(self.midis) != 1:
-            raise Exception('harmonic can only be added to chords with one midi')
-        self.add_midi(self.midis[0].value + interval)
-        self.midis[-1].add_notehead('diamond', filled='no')
-
     @property
     def is_adjoinable(self):
         return self._is_adjoinable
@@ -208,21 +196,6 @@ class TreeChord(XMLTree):
             return True
         return False
 
-    def set_tie_orientation(self, orientation):
-        if self.is_tied_to_next:
-            tied = [t for t in self.get_children_by_type(Notations)[0].get_children_by_type(Tied) if t.type == 'start']
-            for t in tied:
-                t.orientation = orientation
-
-    def to_rest(self):
-        self.midis = [0]
-        self.remove_tie('stop')
-        self.remove_tie('start')
-        for notation in self.get_children_by_type(Notations):
-            articulations = notation.get_children_by_type(Articulations)
-            for articulation in articulations:
-                notation.remove_child(articulation)
-
     @property
     def position_in_beat(self):
         index_in_beat = self.parent_beat.chords.index(self)
@@ -290,77 +263,61 @@ class TreeChord(XMLTree):
         except IndexError:
             return []
 
-    # def add_finger_tremolo(self, chord, number=3):
-    #     self.finger_tremolo = FingerTremolo(chord, number)
+    @property
+    def _notes(self):
+        output = []
+        if self.zero_mode == 'remove' and self.quarter_duration == 0:
+            return output
 
-    def add_flag(self, flag):
-        if not isinstance(flag, TreeChordFlag) and not isinstance(flag, TreeChordFlag2) \
-                and not isinstance(flag, TreeChordFlag3):
-            raise TypeError(
-                'flag must be of type TreeChordFlag, TreeChordFlag2 or TreeChordFlag3 not {}'.format(flag.__class__))
-        if self._flags is None:
-            self._flags = set()
-        self._flags.add(flag)
+        for index, midi in enumerate(self.midis):
+            note = TreeNote(event=midi.get_pitch_rest(), quarter_duration=self.quarter_duration, parent_chord=self)
+            note.is_finger_tremolo = self.is_finger_tremolo
+            if self.relative_x is not None:
+                note.relative_x = self.relative_x
+            if midi.notehead:
+                note.add_child(midi.notehead)
 
-    def remove_flag(self, flag):
-        if flag in self._flags:
-            self._flags.remove(flag)
+            for child in self.get_children():
+                if isinstance(child, Lyric) and index != 0:
+                    pass
 
-    def add_slur_object(self, slur):
-        try:
-            notations = self.get_children_by_type(Notations)[0]
-        except IndexError:
-            notations = self.add_child(Notations())
+                elif isinstance(child, Notations) and index != 0:
+                    grandchildren = child.get_children()
+                    for grandchild in grandchildren:
+                        if type(grandchild) not in (Ornaments, Technical, Articulations, Dynamics):
+                            note._add_notations(grandchild)
+                elif isinstance(child, Direction):
+                    pass
+                elif isinstance(child, Attributes):
+                    pass
+                else:
+                    note.add_child(child)
+            if index > 0:
+                note.add_child(Chord())
+            output.append(note)
+        return output
 
-        notations.add_child(slur)
-        return slur
+    def add_midi(self, val):
+        if val == 0:
+            raise ValueError('midi with value 0 can not be added.')
 
-    def add_slur(self, type, **kwargs):
-        slur = Slur(type, **kwargs)
-        return self.add_slur_object(slur)
+        if not isinstance(val, Midi):
+            val = Midi(val)
 
-    def remove_slur(self, type):
-        try:
-            notations = self.get_children_by_type(Notations)[0]
-            slurs = [s for s in notations.get_children_by_type(Slur) if s.type == type]
-            for slur in slurs:
-                notations.remove_child(slur)
-            if not notations.get_children():
-                self.remove_child(notations)
-        except IndexError:
-            pass
+        self._midis.append(val)
 
-    def add_notations_object(self, object):
-        try:
-            notations = self.get_children_by_type(Notations)[0]
-        except IndexError:
-            notations = self.add_child(Notations())
+    def add_harmonic(self, interval):
+        if len(self.midis) != 1:
+            raise Exception('harmonic can only be added to chords with one midi')
+        self.add_midi(self.midis[0].value + interval)
+        self.midis[-1].add_notehead('diamond', filled='no')
 
-        notations.add_child(object)
-        return object
+    def set_voice_number(self, voice_number):
+        self.manual_voice_number = voice_number
 
-    def remove_notations(self):
-        notations = self.get_children_by_type(Notations)
-        for notation in notations:
-            self.remove_child(notation)
-
-    def add_slide(self, type, **kwargs):
-        object = Slide(type, **kwargs)
-        return self.add_notations_object(object)
-
-    def add_tremolo(self, number=3, **kwargs):
-
-        try:
-            notations = self.get_children_by_type(Notations)[0]
-        except IndexError:
-            notations = self.add_child(Notations())
-
-        try:
-            ornaments = notations.get_children_by_type(Ornaments)[0]
-        except IndexError:
-            ornaments = notations.add_child(Ornaments())
-
-        ornaments.add_child(Tremolo(number, **kwargs))
+    def remove_voice(self):
+        for voice in self.get_children_by_type(Voice):
+            self.remove_child(voice)
 
     def split_copy(self, quarter_duration):
         new_chord = TreeChord(quarter_duration=quarter_duration)
@@ -426,39 +383,233 @@ class TreeChord(XMLTree):
 
         return new_chords
 
-    @property
-    def _notes(self):
-        output = []
-        if self.zero_mode == 'remove' and self.quarter_duration == 0:
-            return output
+    def add_flag(self, flag):
+        if not isinstance(flag, TreeChordFlag) and not isinstance(flag, TreeChordFlag2) \
+                and not isinstance(flag, TreeChordFlag3):
+            raise TypeError(
+                'flag must be of type TreeChordFlag, TreeChordFlag2 or TreeChordFlag3 not {}'.format(flag.__class__))
+        if self._flags is None:
+            self._flags = set()
+        self._flags.add(flag)
 
-        for index, midi in enumerate(self.midis):
-            note = TreeNote(event=midi.get_pitch_rest(), quarter_duration=self.quarter_duration, parent_chord=self)
-            note.is_finger_tremolo = self.is_finger_tremolo
-            if self.relative_x is not None:
-                note.relative_x = self.relative_x
-            if midi.notehead:
-                note.add_child(midi.notehead)
+    def remove_flag(self, flag):
+        if flag in self._flags:
+            self._flags.remove(flag)
 
-            for child in self.get_children():
-                if isinstance(child, Lyric) and index != 0:
-                    pass
+    def set_manual_type(self, val, **kwargs):
+        try:
+            chord_type = self.get_children_by_type(Type)[0]
+            self.remove_child(chord_type)
+        except IndexError:
+            self.add_child(Type(value=val, **kwargs))
 
-                elif isinstance(child, Notations) and index != 0:
-                    grandchildren = child.get_children()
-                    for grandchild in grandchildren:
-                        if type(grandchild) not in (Ornaments, Technical, Articulations, Dynamics):
-                            note._add_notations(grandchild)
-                elif isinstance(child, Direction):
-                    pass
-                elif isinstance(child, Attributes):
-                    pass
-                else:
-                    note.add_child(child)
-            if index > 0:
-                note.add_child(Chord())
-            output.append(note)
-        return output
+        self._manual_type = True
+
+    def set_manual_dots(self, val):
+        try:
+            for dot in self.get_children_by_type(Dot):
+                self.remove_child(dot)
+        except IndexError:
+            pass
+        for i in range(val):
+            self.add_child(Dot())
+
+        self._manual_dots = True
+
+    def update_type(self):
+        """get type of a Note() depending on its quantized duration and return it [whole, half, quarter, eighth, 16th,
+        32nd, 64th]"""
+        _types = {(1, 12): '32nd',
+                  (1, 11): '32nd',
+                  (2, 11): '16th',
+                  (3, 11): '16th',
+                  (4, 11): 'eighth',
+                  (6, 11): 'eighth',
+                  (8, 11): 'quarter',
+                  (1, 10): '32nd',
+                  (3, 10): '16th',
+                  (1, 9): '32nd',
+                  (2, 9): '16th',
+                  (4, 9): 'eighth',
+                  (8, 9): 'quarter',
+                  (1, 8): '32nd',
+                  (3, 8): '16th',
+                  (7, 8): 'eighth',
+                  (1, 7): '16th',
+                  (2, 7): 'eighth',
+                  (3, 7): 'eighth',
+                  (4, 7): 'quarter',
+                  (6, 7): 'quarter',
+                  (1, 6): '16th',
+                  (1, 5): '16th',
+                  (2, 5): 'eighth',
+                  (3, 5): 'eighth',
+                  (4, 5): 'quarter',
+                  (1, 4): '16th',
+                  (2, 4): 'eighth',
+                  (3, 4): 'eighth',
+                  (7, 4): 'quarter',
+                  (1, 3): 'eighth',
+                  (2, 3): 'quarter',
+                  (3, 2): 'quarter',
+                  (1, 2): 'eighth',
+                  (1, 1): 'quarter',
+                  (2, 1): 'half',
+                  (3, 1): 'half',
+                  (4, 1): 'whole',
+                  (6, 1): 'whole',
+                  (8, 1): 'breve',
+                  (12, 1): 'breve'
+                  }
+
+        if self._manual_type is False:
+            tremoli_types = [tremolo.type for tremolo in self.tremoli]
+
+            if self.quarter_duration == 0:
+                value = 'eighth'
+
+            elif ('start' in tremoli_types or 'stop' in tremoli_types):
+                show_duration = self.quarter_duration * 2
+                value = _types[(show_duration.numerator, show_duration.denominator)]
+                if not self.get_children_by_type(TimeModification):
+                    tm = TimeModification()
+                    tm.add_child(ActualNotes(2))
+                    tm.add_child(NormalNotes(1))
+                    self.add_child(tm)
+            else:
+                value = _types[(self.quarter_duration.numerator, self.quarter_duration.denominator)]
+
+            try:
+                chord_type = self.get_children_by_type(Type)[0]
+                chord_type.value = value
+            except IndexError:
+                self.add_child(Type(value))
+
+    def update_dot(self):
+        if self._manual_dots is False:
+            _dot = 0
+
+            if self.quarter_duration.numerator % 3 == 0:
+                _dot = 1
+            elif self.quarter_duration == Fraction(1, 2) and self.parent_beat.best_div == 6:
+                _dot = 1
+            elif self.quarter_duration == Fraction(1, 4) and self.parent_beat.best_div == 6:
+                _dot = 1
+            elif (self.quarter_duration == Fraction(3, 9) or self.quarter_duration == Fraction(6,
+                                                                                               9)) and self.parent_beat.best_div == 9:
+                _dot = 1
+            elif self.quarter_duration == Fraction(7, 8):
+                _dot = 2
+            elif self.quarter_duration == Fraction(7, 4):
+                _dot = 2
+            else:
+                _dot = 0
+
+            for dot in self.get_children_by_type(Dot):
+                self.remove_child(dot)
+
+            for i in range(_dot):
+                self.add_child(Dot())
+
+    def tremolo_flag_copy(self):
+        new_chord = TreeChord()
+        new_chord.midis = self.midis
+        return new_chord
+
+    def transpose(self, interval):
+        for midi in self.midis:
+            if midi.value != 0:
+                midi.value += interval
+
+    def inverse(self):
+        intervals = xToD([midi.value for midi in self.midis])
+        intervals = [-interval for interval in intervals]
+        self.midis = dToX(intervals, first_element=self.midis[0].value)
+
+    def change_range(self, min_midi, max_midi, microtone=2):
+        if self.is_rest:
+            pass
+        else:
+            scale = Scale(self.midis[0].value, self.midis[-1].value, min_midi, max_midi, step=2 / microtone)
+            self.midis = [scale(midi.value) for midi in self.midis]
+
+    def add_lyric(self, text, number=1, **kwargs):
+        lyric = self.add_child(Lyric(number=str(number), **kwargs))
+        lyric.add_child(Text(str(text)))
+        return lyric
+
+    # //// Clef
+    def add_clef(self, clef):
+        try:
+            attributes = self.get_children_by_type(Attributes)[0]
+        except IndexError:
+            attributes = self.add_child(Attributes())
+
+        attributes.add_child(clef)
+
+    def get_clef(self):
+        try:
+            attributes = self.get_children_by_type(Attributes)[0]
+            return attributes.get_children_by_type(TreeClef)[0]
+        except IndexError:
+            return None
+
+    # Notations
+    def add_notations_object(self, object):
+        try:
+            notations = self.get_children_by_type(Notations)[0]
+        except IndexError:
+            notations = self.add_child(Notations())
+
+        notations.add_child(object)
+        return object
+
+    def remove_notations(self):
+        notations = self.get_children_by_type(Notations)
+        for notation in notations:
+            self.remove_child(notation)
+
+    def add_slide(self, type, **kwargs):
+        object = Slide(type, **kwargs)
+        return self.add_notations_object(object)
+
+    def add_slur_object(self, slur):
+        try:
+            notations = self.get_children_by_type(Notations)[0]
+        except IndexError:
+            notations = self.add_child(Notations())
+
+        notations.add_child(slur)
+        return slur
+
+    def add_slur(self, type, **kwargs):
+        slur = Slur(type, **kwargs)
+        return self.add_slur_object(slur)
+
+    def remove_slur(self, type):
+        try:
+            notations = self.get_children_by_type(Notations)[0]
+            slurs = [s for s in notations.get_children_by_type(Slur) if s.type == type]
+            for slur in slurs:
+                notations.remove_child(slur)
+            if not notations.get_children():
+                self.remove_child(notations)
+        except IndexError:
+            pass
+
+    def add_tremolo(self, number=3, **kwargs):
+
+        try:
+            notations = self.get_children_by_type(Notations)[0]
+        except IndexError:
+            notations = self.add_child(Notations())
+
+        try:
+            ornaments = notations.get_children_by_type(Ornaments)[0]
+        except IndexError:
+            ornaments = notations.add_child(Ornaments())
+
+        ornaments.add_child(Tremolo(number, **kwargs))
 
     def add_tie(self, value):
         if value not in ('stop', 'start'):
@@ -504,9 +655,11 @@ class TreeChord(XMLTree):
             except AttributeError:
                 pass
 
-    def remove_voice(self):
-        for voice in self.get_children_by_type(Voice):
-            self.remove_child(voice)
+    def set_tie_orientation(self, orientation):
+        if self.is_tied_to_next:
+            tied = [t for t in self.get_children_by_type(Notations)[0].get_children_by_type(Tied) if t.type == 'start']
+            for t in tied:
+                t.orientation = orientation
 
     def add_tuplet(self, type, number=1):
         normals = {3: 2, 5: 4, 6: 4, 7: 4, 9: 8, 10: 8, 11: 8, 12: 8, 13: 8, 14: 8, 15: 8}
@@ -604,141 +757,40 @@ class TreeChord(XMLTree):
                 output.extend(articulation.get_children())
         return output
 
-    def set_manual_type(self, val, **kwargs):
+    def to_rest(self):
+        self.midis = [0]
+        self.remove_tie('stop')
+        self.remove_tie('start')
+        for notation in self.get_children_by_type(Notations):
+            articulations = notation.get_children_by_type(Articulations)
+            for articulation in articulations:
+                notation.remove_child(articulation)
+
+    def add_fermata(self, value='normal', **kwargs):
+        fermata = Fermata(value, **kwargs)
         try:
-            chord_type = self.get_children_by_type(Type)[0]
-            self.remove_child(chord_type)
+            notations = self.get_children_by_type(Notations)[0]
         except IndexError:
-            self.add_child(Type(value=val, **kwargs))
+            notations = self.add_child(Notations())
 
-        self.manual_type = True
+        notations.add_child(fermata)
 
-    def update_type(self):
-        """get type of a Note() depending on its quantized duration and return it [whole, half, quarter, eighth, 16th,
-        32nd, 64th]"""
-        _types = {(1, 12): '32nd',
-                  (1, 11): '32nd',
-                  (2, 11): '16th',
-                  (3, 11): '16th',
-                  (4, 11): 'eighth',
-                  (6, 11): 'eighth',
-                  (8, 11): 'quarter',
-                  (1, 10): '32nd',
-                  (3, 10): '16th',
-                  (1, 9): '32nd',
-                  (2, 9): '16th',
-                  (4, 9): 'eighth',
-                  (8, 9): 'quarter',
-                  (1, 8): '32nd',
-                  (3, 8): '16th',
-                  (7, 8): 'eighth',
-                  (1, 7): '16th',
-                  (2, 7): 'eighth',
-                  (3, 7): 'eighth',
-                  (4, 7): 'quarter',
-                  (6, 7): 'quarter',
-                  (1, 6): '16th',
-                  (1, 5): '16th',
-                  (2, 5): 'eighth',
-                  (3, 5): 'eighth',
-                  (4, 5): 'quarter',
-                  (1, 4): '16th',
-                  (2, 4): 'eighth',
-                  (3, 4): 'eighth',
-                  (7, 4): 'quarter',
-                  (1, 3): 'eighth',
-                  (2, 3): 'quarter',
-                  (3, 2): 'quarter',
-                  (1, 2): 'eighth',
-                  (1, 1): 'quarter',
-                  (2, 1): 'half',
-                  (3, 1): 'half',
-                  (4, 1): 'whole',
-                  (6, 1): 'whole',
-                  (8, 1): 'breve',
-                  (12, 1): 'breve'
-                  }
+    # /// directions
+    def _get_direction_types(self):
+        output = []
+        for direction in self.get_children_by_type(Direction):
+            for dt in direction.get_children_by_type(DirectionType):
+                output.append(dt)
+        return output
 
-        if self.manual_type is False:
-            tremoli_types = [tremolo.type for tremolo in self.tremoli]
+    def _remove_direction(self, direction):
+        self.remove_child(direction)
 
-            if self.quarter_duration == 0:
-                value = 'eighth'
-
-            elif ('start' in tremoli_types or 'stop' in tremoli_types):
-                show_duration = self.quarter_duration * 2
-                value = _types[(show_duration.numerator, show_duration.denominator)]
-                if not self.get_children_by_type(TimeModification):
-                    tm = TimeModification()
-                    tm.add_child(ActualNotes(2))
-                    tm.add_child(NormalNotes(1))
-                    self.add_child(tm)
-            else:
-                value = _types[(self.quarter_duration.numerator, self.quarter_duration.denominator)]
-
-            try:
-                chord_type = self.get_children_by_type(Type)[0]
-                chord_type.value = value
-            except IndexError:
-                self.add_child(Type(value))
-
-    def update_dot(self):
-        _dot = 0
-
-        if self.quarter_duration.numerator % 3 == 0:
-            _dot = 1
-        elif self.quarter_duration == Fraction(1, 2) and self.parent_beat.best_div == 6:
-            _dot = 1
-        elif self.quarter_duration == Fraction(1, 4) and self.parent_beat.best_div == 6:
-            _dot = 1
-        elif (self.quarter_duration == Fraction(3, 9) or self.quarter_duration == Fraction(6,
-                                                                                           9)) and self.parent_beat.best_div == 9:
-            _dot = 1
-        elif self.quarter_duration == Fraction(7, 8):
-            _dot = 2
-        elif self.quarter_duration == Fraction(7, 4):
-            _dot = 2
-        else:
-            _dot = 0
-
-        for dot in self.get_children_by_type(Dot):
-            self.remove_child(dot)
-
-        for i in range(_dot):
-            self.add_child(Dot())
-
-    # def copy(self):
-    #     new_chord = TreeChord(quarter_duration=self.quarter_duration)
-    #     new_chord.midis = self.midis
-    #     for child in self.get_children():
-    #         new_chord.add_child(child)
-
-    def tremolo_flag_copy(self):
-        new_chord = TreeChord()
-        new_chord.midis = self.midis
-        return new_chord
-
-    def transpose(self, interval):
-        for midi in self.midis:
-            if midi.value != 0:
-                midi.value += interval
-
-    def inverse(self):
-        intervals = xToD([midi.value for midi in self.midis])
-        intervals = [-interval for interval in intervals]
-        self.midis = dToX(intervals, first_element=self.midis[0].value)
-
-    def change_range(self, min_midi, max_midi, microtone=2):
-        if self.is_rest:
-            pass
-        else:
-            scale = Scale(self.midis[0].value, self.midis[-1].value, min_midi, max_midi, step=2 / microtone)
-            self.midis = [scale(midi.value) for midi in self.midis]
-
-    def add_lyric(self, text, number=1, **kwargs):
-        lyric = self.add_child(Lyric(number=str(number), **kwargs))
-        lyric.add_child(Text(str(text)))
-        return lyric
+    def _remove_direction_type(self, direction_type):
+        parent = direction_type.up
+        parent.remove_child(direction_type)
+        if not parent.get_children():
+            self._remove_direction(parent)
 
     def add_dynamics(self, value, placement='below', **kwargs):
         dynamic_classes = [P, PP, PPP, PPPP, PPPPP, PPPPPP, F, FF, FFF, FFFF, FFFFF, FFFFFF, MP, MF, SF, SFP, SFPP, FP,
@@ -758,8 +810,15 @@ class TreeChord(XMLTree):
 
         return dynamics
 
-    @property
-    def dynamics(self):
+    def remove_dynamics(self):
+        for direction_type in self._get_direction_types():
+            for child in direction_type.get_children():
+                if isinstance(child, Dynamics):
+                    direction_type.remove_child(child)
+            if not direction_type.get_children():
+                self._remove_direction_type(direction_type)
+
+    def get_dynamics(self):
         directions = self.get_children_by_type(Direction)
         for direction in directions:
             direction_types = direction.get_children_by_type(DirectionType)
@@ -769,29 +828,6 @@ class TreeChord(XMLTree):
                         return child.get_children()[0].to_string()[1:-3]
         return None
 
-    def get_dynamics(self):
-        return self.dynamics
-
-    def add_wedge(self, value, placement='below', **kwargs):
-        wedge_object = Wedge(value, **kwargs)
-
-        direction = self.add_child(Direction(placement=placement))
-        direction_type = direction.add_child(DirectionType())
-        wedge = direction_type.add_child(wedge_object)
-        #
-        # dynamics.add_child(dynamic_classes[index]())
-
-        return wedge
-
-    def add_fermata(self, value='normal', **kwargs):
-        fermata = Fermata(value, **kwargs)
-        try:
-            notations = self.get_children_by_type(Notations)[0]
-        except IndexError:
-            notations = self.add_child(Notations())
-
-        notations.add_child(fermata)
-
     def add_action_dynamics(self, value, **kwargs):
         dynamics = self.add_dynamics(value, **kwargs)
         direction = dynamics.up.up
@@ -807,39 +843,66 @@ class TreeChord(XMLTree):
         direction_type = direction.add_child(DirectionType())
         direction_type.add_child(Words(value=' "', font_size=20))
 
+    def add_wedge(self, value, placement='below', **kwargs):
+        wedge_object = Wedge(value, **kwargs)
+
+        direction = self.add_child(Direction(placement=placement))
+        direction_type = direction.add_child(DirectionType())
+        wedge = direction_type.add_child(wedge_object)
+        #
+        # dynamics.add_child(dynamic_classes[index]())
+
+        return wedge
+
     def add_bracket(self, type, line_end, placement='above', **kwargs):
         d = self.add_child(Direction(placement=placement))
         dt = d.add_child(DirectionType())
         dt.add_child(Bracket(type=type, line_end=line_end, **kwargs))
 
-    def add_words(self, text, placement='above', **kwargs):
+    def add_words(self, words, placement='above', **kwargs):
         d = self.add_child(Direction(placement=placement))
         dt = d.add_child(DirectionType())
-        dt.add_child(Words(value=str(text), **kwargs))
+        if isinstance(words, Words):
+            if kwargs:
+                raise ValueError('no keywords possible if add_words gets a Words()')
+            dt.add_child(words)
+        else:
+            dt.add_child(Words(value=str(words), **kwargs))
 
-    def get_direction_types(self):
-        output = []
-        for direction in self.get_children_by_type(Direction):
-            for dt in direction.get_children_by_type(DirectionType):
-                output.append(dt)
-        return output
+    def add_grace_chords(self, chords, mode='pre'):
+        permitted = ['pre', 'post']
+        if mode not in permitted:
+            raise ValueError('mode must be in {}'.format(permitted))
+        try:
+            chords = list(chords)
+        except TypeError:
+            chords = [chords]
+
+        for chord in chords:
+            if not isinstance(chord, TreeChord):
+                raise TypeError('wrong type {}'.format(type(chord)))
+        for chord in chords:
+            chord.quarter_duration = 0
+            chord.zero_mode = 'grace'
+            if mode == 'pre':
+                self._pre_grace_chords.append(chord)
+            else:
+                self._post_grace_chords.append(chord)
+
+    def get_pre_grace_chords(self):
+        return self._pre_grace_chords
+
+    def get_post_grace_chords(self):
+        return self._post_grace_chords
 
     def get_words(self):
         output = []
-        for dt in self.get_direction_types():
+        for dt in self._get_direction_types():
             for child in dt.get_children():
                 if isinstance(child, Words):
                     output.append(child)
         return output
 
-    def add_clef(self, clef):
-        try:
-            attributes = self.get_children_by_type(Attributes)[0]
-        except IndexError:
-            attributes = self.add_child(Attributes())
-
-        attributes.add_child(clef)
-
     def __deepcopy__(self, memodict={}):
         new_chord = TreeChord(quarter_duration=self.quarter_duration, zero_mode=self.zero_mode)
         new_chord.midis = [midi.__deepcopy__() for midi in self.midis]
@@ -859,10 +922,15 @@ class TreeChord(XMLTree):
                 new_chord._flags.append(flag.__deepcopy__())
 
         new_chord._flags = self._flags
-        new_chord.manual_type = self.manual_type
+        new_chord._manual_type = self._manual_type
         new_chord.tie_orientation = self.tie_orientation
         # for attribute in self.__dir__():
         #     print(attribute)
+        for grace_chord in self.get_pre_grace_chords():
+            new_chord.add_grace_chords(grace_chord.__deepcopy__())
+
+        for grace_chord in self.get_post_grace_chords():
+            new_chord.add_grace_chords(grace_chord.__deepcopy__(), 'post')
         return new_chord
 
     def remove_from_score(self):
@@ -896,6 +964,9 @@ class TreeChord(XMLTree):
                 next_chord.add_child(n)
             for d in self.get_children_by_type(Direction):
                 next_chord.add_child(d)
+            clef = self.get_clef()
+            if clef:
+                next_chord.add_clef(clef)
 
         self.parent_beat.chords.remove(self)
         self.parent_voice.chords.remove(self)
@@ -906,4 +977,8 @@ class TreeChord(XMLTree):
         for child in self.get_children():
             if not isinstance(child, Voice):
                 new_chord.add_child(child)
+        for grace_chord in self.get_pre_grace_chords():
+            new_chord.add_grace_chords(grace_chord.deepcopy_for_SimpleFormat())
+        for grace_chord in self.get_post_grace_chords():
+            new_chord.add_grace_chords(grace_chord.deepcopy_for_SimpleFormat().__deepcopy__(), 'post')
         return new_chord
