@@ -1,13 +1,13 @@
 import warnings
 
 from lxml import etree as et
-from musicscore.musictree.treechordflags2 import TreeChordFlag2
 from quicktions import Fraction
 
 from musicscore.basic_functions import lcm, substitute, flatten
 from musicscore.musictree.exceptions import MusicTreeError
 from musicscore.musictree.treebeat import TreeBeat
 from musicscore.musictree.treechord import TreeChord
+from musicscore.musictree.treechordflags2 import TreeChordFlag2
 from musicscore.musictree.treechordflags3 import TreeChordFlag3
 from musicscore.musictree.treenote import TreeNote, TreeBackup
 from musicscore.musicxml.elements import timewise as timewise
@@ -196,6 +196,16 @@ class TreePartVoice(object):
             return None
 
     def add_chord(self, chord):
+        def _append_chord(chord):
+            all_chords = chord.get_pre_grace_chords() + [chord] + chord.get_post_grace_chords()
+            for ch in all_chords:
+                self.chords.append(ch)
+                ch.parent_voice = self
+                if ch.manual_voice_number:
+                    ch.add_child(Voice(str(ch.manual_voice_number)))
+                else:
+                    ch.add_child(Voice(str(self.number)))
+
         # print('treepart add_chord, chord.tie_orientation', chord.tie_orientation)
         remain = chord.quarter_duration - self.remaining_duration
         if self.remaining_duration == 0:
@@ -204,22 +214,14 @@ class TreePartVoice(object):
         elif remain > 0:
             split = chord.split([chord.quarter_duration - remain, remain])
             first_chord = split[0]
-            self.chords.append(first_chord)
-            first_chord.parent_voice = self
-            if first_chord.manual_voice_number:
-                first_chord.add_child(Voice(str(first_chord.manual_voice_number)))
-            else:
-                first_chord.add_child(Voice(str(self.number)))
+            _append_chord(first_chord)
             first_chord._head = True
             split[1]._tail = True
+            split[1].zero_mode = 'remove'
             return split[1]
         else:
-            self.chords.append(chord)
-            chord.parent_voice = self
-            if chord.manual_voice_number:
-                chord.add_child(Voice(str(chord.manual_voice_number)))
-            else:
-                chord.add_child(Voice(str(self.number)))
+            _append_chord(chord)
+            return None
 
     def remove_chords(self):
         self._chords = []
@@ -431,6 +433,7 @@ class TreePartVoice(object):
                     split[1].parent_beat = beat
                     split[0]._head = True
                     split[1]._tail = True
+                    # print([chord.quarter_duration for chord in split])
 
         for beat in self.beats:
             if beat.chords and len([chord for chord in beat.chords if chord.quarter_duration != 0]) != 1:
@@ -446,6 +449,22 @@ class TreePartVoice(object):
                     split[0]._head = True
                     split[1]._tail = True
 
+    def _correct_deviations(self):
+
+        def _get_expected_durations():
+            output = [self.beats[0].duration]
+            for beat in self.beats[1:]:
+                if beat.chords == []:
+                    output[-1] += beat.duration
+                else:
+                    output.append(beat.duration)
+            return output
+
+        expected_durations = _get_expected_durations()
+        for index, beat in enumerate([beat for beat in self.beats if beat.chords]):
+            delta = expected_durations[index] - sum([chord.quarter_duration for chord in beat.chords])
+            beat.chords[-1].quarter_duration += delta
+
     def fill_with_rest(self):
         if not self._filled_with_rest:
             if self.remaining_duration > 0:
@@ -453,6 +472,7 @@ class TreePartVoice(object):
                     self.chords[-1].quarter_duration += Fraction(self.remaining_duration)
                 else:
                     rest = TreeChord(midis=0, quarter_duration=self.remaining_duration)
+                    rest.zero_mode = 'remove'
                     self.add_chord(rest)
             self._filled_with_rest = True
 
@@ -516,6 +536,7 @@ class TreePartVoice(object):
             self.set_beats(list_of_beats)
             self._add_chords_to_beats()
             self._split_chords_beatwise()
+            self._correct_deviations()
             self._beats_added = True
         # else:
         #     warnings.warn('beats already added to {}. No action took place.'.format(self))
@@ -876,7 +897,6 @@ class TreePartVoice(object):
 
 
 class TreePart(timewise.Part):
-    """"""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -894,7 +914,6 @@ class TreePart(timewise.Part):
     @property
     def __name__(self):
         index = self.up.get_children_by_type(self.__class__).index(self)
-        # return self.up.__name__ + ' ' + 'p:' + str(index + 1)
         return self.up.__name__ + '.' + str(index + 1)
 
     @property
@@ -951,13 +970,6 @@ class TreePart(timewise.Part):
         for voice in self.voices.values():
             output.extend(voice.xml_chords)
         return output
-        # output = {}
-        # for note in self.get_children_by_type(TreeNote):
-        #     try:
-        #         output[note.offset].append(note)
-        #     except KeyError:
-        #         output[note.offset] = [note]
-        # return output
 
     def get_divisions(self):
         duration_denominators = [chord.quarter_duration.denominator for chord in
@@ -977,7 +989,6 @@ class TreePart(timewise.Part):
     def set_voice(self, voice_number):
         self.voices[voice_number] = TreePartVoice(voice_number)
         self.voices[voice_number].parent_part = self
-        # self.voices[voice_number].set_beats()
         return self.voices[voice_number]
 
     def get_voice(self, voice_number):
@@ -1016,11 +1027,19 @@ class TreePart(timewise.Part):
         for voice in self.voices.values():
             voice.group_beams()
 
-    def chord_to_notes(self):
+    def chords_to_notes(self):
         for voice in self.voices.values():
             if not voice._dots_updated:
                 raise Exception('update_dots() first')
 
+        if not self.up.previous and self.parent_score_part and self.parent_score_part.instrument:
+            clef = self.parent_score_part.instrument.standard_clef
+            if clef:
+                first_chords = [voice.chords[0] for voice in self.voices.values()]
+                first_clefs = [chord.get_clef() for chord in first_chords if chord.get_clef()]
+                if not first_clefs:
+                    first_chords[0].add_clef(clef)
+
         if not self._chords_notated:
             for index, voice in enumerate(self.voices.values()):
                 if index != 0:
@@ -1259,8 +1278,6 @@ class TreePart(timewise.Part):
 
             self.quantize()
 
-            # self.adjoin_rests_in_beat()
-
             self.split_not_notatable()
 
             self.implement_flags()
@@ -1283,7 +1300,7 @@ class TreePart(timewise.Part):
 
             self.implement_flags_3()
 
-            self.chord_to_notes()
+            self.chords_to_notes()
 
             self.update_divisions()
 
