@@ -13,8 +13,8 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[1, 1, 1, 1])
-        sf_2 = SimpleFormat(durations=[2, 2, 2])
+        sf = SimpleFormat(quarter_durations=[1, 1, 1, 1])
+        sf_2 = SimpleFormat(quarter_durations=[2, 2, 2])
         sf.extend(sf_2)
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
