@@ -13,11 +13,11 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(midis=[70, 72, 73], durations=[2, 0.5, 0.5])
+        sf = SimpleFormat(midis=[70, 72, 73], quarter_durations=[2, 0.5, 0.5])
         voice1 = sf.to_stream_voice(1)
         voice1.add_to_score(self.score, 1, 1)
 
-        sf = SimpleFormat(midis=[50, 52, 53], durations=[0.5, 1, 2])
+        sf = SimpleFormat(midis=[50, 52, 53], quarter_durations=[0.5, 1, 2])
         voice2 = sf.to_stream_voice(2)
         voice2.add_to_score(self.score, 1, 1)
 
