@@ -11,7 +11,7 @@ path = os.path.abspath(__file__).split('.')[0]
 class Test(TestCase):
     def setUp(self) -> None:
         self.score = TreeScoreTimewise()
-        sf = SimpleFormat(durations=[1, 1])
+        sf = SimpleFormat(quarter_durations=[1, 1])
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
 
